@@ -7,15 +7,15 @@ our $VERSION;
 
 =head1 NAME
 
-Test::Aggregate::Builder - Internal overrides for Test::Builder
+Test::Aggregate::Builder - Internal overrides for Test::Builder.
 
 =head1 VERSION
 
-Version 0.34_01
+Version 0.34_02
 
 =cut
 
-$VERSION = '0.34_01';
+$VERSION = '0.34_02';
 
 =head1 SYNOPSIS
 
@@ -56,7 +56,7 @@ END {
 # allows us to minimize the monkey patching.
 
 # XXX We fully-qualify the sub names because PAUSE won't index what it thinks
-# is an attempt to hijeck the Test::Builder namespace.
+# is an attempt to hijack the Test::Builder namespace.
 
 sub Test::Builder::_plan_check {
     my $self = shift;
@@ -71,8 +71,17 @@ sub Test::Builder::no_header { 1 }
 my $plan;
 BEGIN { $plan = \&Test::Builder::plan }
 
+our %SKIP_REASON_FOR;
+
 sub Test::Builder::plan {
     delete $_[0]->{Have_Plan};
+
+    if ( 'skip_all' eq ( $_[1] || '' )) {
+        my $callpack = caller(1);
+        $SKIP_REASON_FOR{$callpack} = $_[2];
+        return;
+    }
+
     my $callpack = caller(1);
     if ( 'tests' eq ( $_[1] || '' ) ) {
         $PLAN_FOR{$callpack} = $_[2];
@@ -86,6 +95,15 @@ sub Test::Builder::plan {
     $plan->(@_);
 }
 
+my $ok;
+BEGIN { $ok = \&Test::Builder::ok }
+
+sub Test::Builder::ok {
+    my $callpack = __check_test_count();
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+    $ok->(@_);
+}
+
 # Called in _ending and prevents the 'you tried to run a test without a
 # plan' error.
 my $_sanity_check;
@@ -96,15 +114,6 @@ sub Test::Builder::_sanity_check {
     $_sanity_check->(@_);
 }
 
-my $ok;
-BEGIN { $ok = \&Test::Builder::ok }
-
-sub Test::Builder::ok {
-    __check_test_count();
-    local $Test::Builder::Level = $Test::Builder::Level + 1;
-    $ok->(@_);
-}
-
 my $skip;
 BEGIN { $skip = \&Test::Builder::skip }
 
@@ -113,10 +122,11 @@ sub Test::Builder::skip {
     $skip->(@_);
 }
 
+# two purposes:  we check the test cout for a package, but we also return the
+# package name
 sub __check_test_count {
-    $DB::single = 1;
-    return unless $CHECK_PLAN;
     my $callpack;
+    return unless $CHECK_PLAN;
     my $stack_level = 1;
     while ( my ( $package, undef, undef, $subroutine ) = caller($stack_level) ) {
         last if 'Test::Aggregate' eq $package;
@@ -132,6 +142,7 @@ sub __check_test_count {
         no warnings 'uninitialized';
         $TESTS_RUN{$callpack} += 1;
     }
+    return $callpack;
 }
 
 END {
@@ -144,7 +155,6 @@ END {
             # use.  As a result, it can be extremely difficult to track
             # this.  We may change this in the future.
             next unless my $file = $FILE_FOR{$package};
-            $DB::single = 1;
             Test::More::is( $TESTS_RUN{$package} || 0,
                 $plan || 0, "Test ($file) should have the correct plan" );
         }
